import { forwardRef, Module } from '@nestjs/common';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { CarritoController } from './carrito.controller';
import { CarritoService } from './carrito.service';
import { Carrito } from './entity/carrito.entity';
import { InformacionCarritoView } from './entity/views/informacion-carrito.view';
import { FullInformacionCarritoView } from './entity/views/full-informacion-carrito.view';
import { CarritoMotivoModule } from '../carrito-motivo/carrito-motivo.module';
import { InstitucionModule } from '../institucion/institucion.module';
import { InstitucionTipoCarritoModule } from '../institucion-tipo-carrito/institucion-tipo-carrito.module';
import { MarcaModule } from '../marca/marca.module';
import { ModeloModule } from '../modelo/modelo.module';
import { ModuloModule } from '../modulo/modulo.module';
import { ValidarUsuarioModule } from '../validar-usuario/validar-usuario.module';

@Module({
  imports: [
    forwardRef(() => CarritoMotivoModule),
    InstitucionModule,
    InstitucionTipoCarritoModule,
    MarcaModule,
    ModeloModule,
    ModuloModule,
    PassportModule.register({ defaultStrategy: 'jwt' }),
    TypeOrmModule.forFeature([
      Carrito,
      InformacionCarritoView,
      FullInformacionCarritoView,
    ]),
    ValidarUsuarioModule,
  ],
  controllers: [CarritoController],
  providers: [CarritoService],
  exports: [CarritoService],
})
export class CarritoModule {}
