import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { EquipoPrograma } from '../../../equipo-programa/entity/equipo-programa.entity';
import { EquipoTipoEntrada } from '../../../equipo-tipo-entrada/entity/equipo-tipo-entrada.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('e.id_equipo', 'id_equipo')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.prestado', 'prestado')
      .addSelect('e.u', 'u')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('ps.id_equipo_programa', 'id_equipo_programa')
      .addSelect('ps.id_programa', 'id_programa')
      .addSelect('tes.id_equipo_tipo_entrada', 'id_equipo_tipo_entrada')
      .addSelect('tes.id_tipo_entrada', 'id_tipo_entrada')
      .addSelect('m.id_institucion', 'id_institucion')
      .from(Equipo, 'e')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(EquipoPrograma, 'ps', 'ps.id_equipo = e.id_equipo')
      .innerJoin(EquipoTipoEntrada, 'tes', 'tes.id_equipo = e.id_equipo')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion')
      .where('i.activo = 1')
      .andWhere('m.activo = 1')
      .andWhere('c.activo = 1')
      .andWhere('e.id_status = 1')
      .orderBy('c.carrito', 'ASC')
      .addOrderBy('e.equipo', 'ASC'),
})
export class InformacionEquipoPrestamoView {
  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_equipo_programa: number;

  @ViewColumn()
  id_equipo_tipo_entrada: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_programa: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_tipo_entrada: number;

  @ViewColumn()
  prestado: number;

  @ViewColumn()
  u: number;
}
