import { Module } from '@nestjs/common';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { UsuarioController } from './usuario.controller';
import { UsuarioService } from './usuario.service';
import { Usuario } from './entity/usuario.entity';
import { FullInformacionUsuarioView } from './entity/views/full-informacion-usuario.view';
import { BcryptModule } from '../bcrypt/bcrypt.module';
import { InstitucionModule } from '../institucion/institucion.module';
import { InstitucionCarreraModule } from '../institucion-carrera/institucion-carrera.module';
import { InstitucionUsuarioModule } from '../institucion-usuario/institucion-usuario.module';
import { NodemailerModule } from '../nodemailer/nodemailer.module';
import { TipoUsuarioModule } from '../tipo-usuario/tipo-usuario.module';
import { ValidarUsuarioModule } from '../validar-usuario/validar-usuario.module';

@Module({
  imports: [
    BcryptModule,
    InstitucionModule,
    InstitucionCarreraModule,
    InstitucionUsuarioModule,
    NodemailerModule,
    PassportModule.register({ defaultStrategy: 'jwt' }),
    TipoUsuarioModule,
    TypeOrmModule.forFeature([
      Usuario,
      FullInformacionUsuarioView,
    ]),
    ValidarUsuarioModule,
  ],
  controllers: [UsuarioController],
  providers: [UsuarioService],
  exports: [UsuarioService],
})
export class UsuarioModule {}
